package com.ruoyi.interfaces.service;

import com.ruoyi.interfaces.domain.PtServiceLog;

import java.util.List;

/**
 * 服务调用日志Service接口
 * 
 * @author 朱得糠
 * @date 2025-09-01
 */
public interface IPtServiceLogService 
{
    /**
     * 查询服务调用日志
     * 
     * @param logId 服务调用日志主键
     * @return 服务调用日志
     */
    public PtServiceLog selectPtServiceLogByLogId(Long logId);

    /**
     * 查询服务调用日志列表
     * 
     * @param ptServiceLog 服务调用日志
     * @return 服务调用日志集合
     */
    public List<PtServiceLog> selectPtServiceLogList(PtServiceLog ptServiceLog);

    /**
     * 新增服务调用日志
     * 
     * @param ptServiceLog 服务调用日志
     * @return 结果
     */
    public int insertPtServiceLog(PtServiceLog ptServiceLog);

    /**
     * 修改服务调用日志
     * 
     * @param ptServiceLog 服务调用日志
     * @return 结果
     */
    public int updatePtServiceLog(PtServiceLog ptServiceLog);

    /**
     * 批量删除服务调用日志
     * 
     * @param logIds 需要删除的服务调用日志主键集合
     * @return 结果
     */
    public int deletePtServiceLogByLogIds(Long[] logIds);

    /**
     * 删除服务调用日志信息
     * 
     * @param logId 服务调用日志主键
     * @return 结果
     */
    public int deletePtServiceLogByLogId(Long logId);

}
